==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/NativeUIContainer.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUIContainer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUIContainer, _super);
    function NativeUIContainer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(NativeUIContainer.prototype, "ar", {
        get: function () {
            return this.ap.getChildrenCount(this.u);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIContainer.prototype, "ap", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    NativeUIContainer.prototype.aq = function (a) {
        return this.ap.getChildAt(this.u, a);
    };
    NativeUIContainer.prototype.au = function (a) {
        this.ap.removeChildAt(this.u, a);
    };
    NativeUIContainer.prototype.as = function (a) {
        this.ap.addChild(this.u, a);
    };
    NativeUIContainer.prototype.at = function (a) {
        this.ap.removeChild(this.u, a);
    };
    NativeUIContainer.$t = markType(NativeUIContainer, 'NativeUIContainer', NativeUIComponent.$);
    return NativeUIContainer;
}(NativeUIComponent));
export { NativeUIContainer };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/NativeUIContainer.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUIContainer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUIContainer, _super);
    function NativeUIContainer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(NativeUIContainer.prototype, "av", {
        get: function () {
            return this.at.getChildrenCount(this.u);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIContainer.prototype, "at", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    NativeUIContainer.prototype.au = function (a) {
        return this.at.getChildAt(this.u, a);
    };
    NativeUIContainer.prototype.ay = function (a) {
        this.at.removeChildAt(this.u, a);
    };
    NativeUIContainer.prototype.aw = function (a) {
        this.at.addChild(this.u, a);
    };
    NativeUIContainer.prototype.ax = function (a) {
        this.at.removeChild(this.u, a);
    };
    NativeUIContainer.$t = markType(NativeUIContainer, 'NativeUIContainer', NativeUIComponent.$);
    return NativeUIContainer;
}(NativeUIComponent));
export { NativeUIContainer };
